summaryrefslogtreecommitdiff
path: root/src/code
diff options
context:
space:
mode:
authorlouist103 <35883445+louist103@users.noreply.github.com>2024-01-14 10:34:50 -0500
committerGitHub <noreply@github.com>2024-01-14 12:34:50 -0300
commita5400fbde5c03c1f5eabd44ff8beceddde0b1c9f (patch)
treefe62abca592578a25a998a7973dd904c3c4e33f5 /src/code
parent5607eec18bae68e4cd38ef6d1fa69d7f1d84bfc8 (diff)
Update ZAPD (#1533)
* git subrepo pull --force tools/ZAPD subrepo: subdir: "tools/ZAPD" merged: "2b6f459b9" upstream: origin: "https://github.com/zeldaret/ZAPD.git" branch: "master" commit: "2b6f459b9" git-subrepo: version: "0.4.6" origin: "???" commit: "???" * Update ZAPD Co-authored-by: Yanis42 <35189056+Yanis42@users.noreply.github.com> * git subrepo pull --force tools/ZAPD subrepo: subdir: "tools/ZAPD" merged: "572b13236" upstream: origin: "https://github.com/zeldaret/ZAPD.git" branch: "master" commit: "572b13236" git-subrepo: version: "0.4.6" origin: "???" commit: "???" * git subrepo pull --force tools/ZAPD subrepo: subdir: "tools/ZAPD" merged: "9601f2699" upstream: origin: "https://github.com/zeldaret/ZAPD.git" branch: "master" commit: "9601f2699" git-subrepo: version: "0.4.6" origin: "???" commit: "???" * fixes for new ZAPD * readd typedefs * remov enums * Reading is hard --------- Co-authored-by: Yanis42 <35189056+Yanis42@users.noreply.github.com>
Diffstat (limited to 'src/code')
-rw-r--r--src/code/PreRender.c1
-rw-r--r--src/code/z_eventmgr.c16
-rw-r--r--src/code/z_play.c4
3 files changed, 11 insertions, 10 deletions
diff --git a/src/code/PreRender.c b/src/code/PreRender.c
index d058fded3..70963d126 100644
--- a/src/code/PreRender.c
+++ b/src/code/PreRender.c
@@ -16,6 +16,7 @@
#include "slowly.h"
#include "stack.h"
#include "stackcheck.h"
+#include "prevent_bss_reordering.h"
/**
* Assigns the "save" values in PreRender
diff --git a/src/code/z_eventmgr.c b/src/code/z_eventmgr.c
index d682ed4f4..5bad9f1a1 100644
--- a/src/code/z_eventmgr.c
+++ b/src/code/z_eventmgr.c
@@ -8,7 +8,7 @@
#include "z64shrink_window.h"
#include "libc/string.h"
-ActorCutscene sGlobalCutsceneList[] = {
+CutsceneEntry sGlobalCutsceneList[] = {
// CS_ID_GLOBAL_78
{ -100, -1, CS_CAM_ID_NONE, CS_SCRIPT_ID_NONE, CS_ID_NONE, CS_END_SFX_NONE_ALT, 255, CS_HUD_VISIBILITY_ALL_ALT, 255,
255 },
@@ -57,7 +57,7 @@ CutsceneManager sCutsceneMgr = {
CS_ID_NONE, 0, CS_ID_NONE, SUB_CAM_ID_DONE, NULL, CS_START_0, NULL, CAM_ID_MAIN, false,
};
-ActorCutscene* sSceneCutsceneList;
+CutsceneEntry* sSceneCutsceneList;
s16 sSceneCutsceneCount;
u8 sWaitingCutsceneList[16];
static s32 sBssPad;
@@ -110,7 +110,7 @@ s16 CutsceneManager_SetHudVisibility(s16 csHudVisibility) {
return hudVisibility;
}
-ActorCutscene* CutsceneManager_GetCutsceneEntryImpl(s16 csId) {
+CutsceneEntry* CutsceneManager_GetCutsceneEntryImpl(s16 csId) {
if (csId < CS_ID_GLOBAL_78) {
return &sSceneCutsceneList[csId];
} else {
@@ -119,7 +119,7 @@ ActorCutscene* CutsceneManager_GetCutsceneEntryImpl(s16 csId) {
}
}
-void CutsceneManager_Init(PlayState* play, ActorCutscene* cutsceneList, s16 numEntries) {
+void CutsceneManager_Init(PlayState* play, CutsceneEntry* cutsceneList, s16 numEntries) {
s32 i;
sSceneCutsceneList = cutsceneList;
@@ -204,7 +204,7 @@ s16 CutsceneManager_MarkNextCutscenes(void) {
#define CUR_CAM sCutsceneMgr.play->cameraPtrs[sCutsceneMgr.subCamId]
void CutsceneManager_End(void) {
- ActorCutscene* csEntry;
+ CutsceneEntry* csEntry;
s16 oldCamId;
s16 oldStateFlags;
@@ -375,7 +375,7 @@ s16 CutsceneManager_StartWithPlayerCsAndSetFlag(s16 csId, Actor* actor) {
}
s16 CutsceneManager_Start(s16 csId, Actor* actor) {
- ActorCutscene* csEntry;
+ CutsceneEntry* csEntry;
Camera* subCam;
Camera* retCam;
s32 csType = 0;
@@ -444,7 +444,7 @@ s16 CutsceneManager_Start(s16 csId, Actor* actor) {
}
s16 CutsceneManager_Stop(s16 csId) {
- ActorCutscene* csEntry;
+ CutsceneEntry* csEntry;
if (csId <= CS_ID_NONE) {
return csId;
@@ -472,7 +472,7 @@ s16 CutsceneManager_GetCurrentCsId(void) {
return sCutsceneMgr.csId;
}
-ActorCutscene* CutsceneManager_GetCutsceneEntry(s16 csId) {
+CutsceneEntry* CutsceneManager_GetCutsceneEntry(s16 csId) {
return CutsceneManager_GetCutsceneEntryImpl(csId);
}
diff --git a/src/code/z_play.c b/src/code/z_play.c
index bd19cbc94..046eae676 100644
--- a/src/code/z_play.c
+++ b/src/code/z_play.c
@@ -2040,7 +2040,7 @@ s16 sPlayerCsIdToCsCamId[] = {
/**
* Extract the common cutscene ids used by Player from the scene and set the cutscene ids in this->playerCsIds.
* If a playerCsId is not present in the scene, then that particular id is set to CS_ID_NONE.
* Otherwise, if there is an ActorCutscene where csCamId matches the appropriate element of sPlayerCsIdToCsCamId,
* set the corresponding playerActorCsId (and possibly change its priority for the zeroth one).
*/
void Play_AssignPlayerCsIdsFromScene(GameState* thisx, s32 spawnCsId) {
@@ -2050,7 +2050,7 @@ void Play_AssignPlayerCsIdsFromScene(GameState* thisx, s32 spawnCsId) {
s16* csCamId = sPlayerCsIdToCsCamId;
for (i = 0; i < ARRAY_COUNT(this->playerCsIds); i++, curPlayerCsId++, csCamId++) {
- ActorCutscene* csEntry;
+ CutsceneEntry* csEntry;
s32 curCsId;
*curPlayerCsId = CS_ID_NONE;
@@ -2040,7 +2040,7 @@ s16 sPlayerCsIdToCsCamId[] = {
* Extract the common cutscene ids used by Player from the scene and set the cutscene ids in this->playerCsIds.
* If a playerCsId is not present in the scene, then that particular id is set to CS_ID_NONE.
- * Otherwise, if there is an ActorCutscene where csCamId matches the appropriate element of sPlayerCsIdToCsCamId,
+ * Otherwise, if there is an CutsceneEntry where csCamId matches the appropriate element of sPlayerCsIdToCsCamId,
* set the corresponding playerActorCsId (and possibly change its priority for the zeroth one).
*/